@@ -4,11 +4,11 @@ correctTaxo = function (genus, species = NULL, score = 0.5)
   
   # Create a dataframe with the original values
   oriData <- data.frame(genus = as.character(genus), query = as.character(genus), id = 1:length(genus))
-    
+  
   # Create a temporary vector with only the unique of the names
   query <- na.omit(unique(genus))
   
-  if(!is.null(species)) 
+  if(!is.null(species))
   {
     # Check the length of the inputs
     if(length(genus) != length(species))
@@ -21,11 +21,13 @@ correctTaxo = function (genus, species = NULL, score = 0.5)
     # Create a temporary vector with only the unique of the names
     query <- unique(paste(genus, species))
     query <- na.omit(query)
+  }else{
+    species <- sapply(strsplit(genus," "),"[",2)
   }
-  
+  species <- as.character(species)
   if (length(query) < 1 || is.na(query)) 
     stop("Please supply at least one name", call. = FALSE)
-
+  
   getpost <- "get"
   if(length(query) > 50)
     getpost <- "post"
@@ -77,14 +79,19 @@ correctTaxo = function (genus, species = NULL, score = 0.5)
     }
     out <- tc(output$names)
     
-    for(j in 1:length(out))
-    {
-      if(length(out[[j]][[2]][[1]]$annotations) == 0)
-        out[[j]][[2]][[1]]$annotations <- list(Authority = NA)
-      
-      tmp <- data.frame(out[[j]][[2]][[1]])
-      tmp$submittedName <- out[[j]]$submittedName
-      df <- rbind(df, tmp)
+    if(length(out)>0){
+      for(j in 1:length(out))
+      {
+        if(length(out[[j]][[2]][[1]]$annotations) == 0)
+          out[[j]][[2]][[1]]$annotations <- list(Authority = NA)
+        
+        tmp <- data.frame(out[[j]][[2]][[1]])
+        tmp$submittedName <- out[[j]]$submittedName
+        df <- rbind(df, tmp)
+      }
+    }else{
+      tmp=data.frame(acceptedName=NA,sourceId=NA,score=0,matchedName=NA,Authority=NA,uri=NA,submittedName=x)
+      df <- rbind(df,tmp)
     }
   }
   
@@ -93,19 +100,19 @@ correctTaxo = function (genus, species = NULL, score = 0.5)
   df$submittedName <- gsub("\r", "", df$submittedName)
   df$matchedName <- gsub("\"", "", df$matchedName)
   df$matchedName <- gsub("\r", "", df$matchedName)
-  
+  df$nameModified <- TRUE
   #### AUTOMATIC PROCEDURE
   # If score ok
   df$outName[df$score >= score] <- df$matchedName[df$score >= score]
   
   # If score non ok
   df$outName[df$score < score] <- df$submittedName[df$score < score]
-    
-  df <- unique(df[, c("submittedName", "outName")])
+  df$nameModified[df$score < score] <- "NoMatch(low_score)"
+  
+  df <- unique(df[, c("submittedName", "outName","nameModified")])
   df <- df[with(df, order(submittedName)), ]
   
-  df$nameModified <- TRUE
-  df$nameModified[!is.na(df$outName) & df$outName == df$submittedName] <- FALSE
+  df$nameModified[!is.na(df$outName) & df$outName == df$submittedName & df$nameModified != "NoMatch(low_score)"] <- FALSE
   
   out <- merge(oriData, df, by.x = "query", by.y = "submittedName", all.x = T)
   out$nameModified[is.na(out$nameModified)] <- TRUE
@@ -114,5 +121,16 @@ correctTaxo = function (genus, species = NULL, score = 0.5)
   out$genusCorrected <- sapply(strsplit(out$outName, "[ ]"), "[", 1)
   out$speciesCorrected <- sapply(strsplit(out$outName, "[ ]"), "[", 2)
   
+  # # If genera or species not found by TNRS
+  # Genera
+  filt <- out$nameModified==TRUE & is.na(out$genusCorrected) & !is.na(out$genus)
+  out$genusCorrected[filt] <- sapply(strsplit(out$genus[filt]," "),"[",1)
+  out$nameModified[filt] <- "TaxaNotFound"
+  # Species
+  filt <- (out$nameModified==TRUE | out$nameModified=="TaxaNotFound") & is.na(out$speciesCorrected) & !is.na(species)
+  out$speciesCorrected[filt] <- species[filt]
+  filt2 <- out$nameModified!="TaxaNotFound"
+  out$nameModified[filt & filt2] <- "SpNotFound"
+  
   return(out[, c("genusCorrected", "speciesCorrected", "nameModified")])
-}
\ No newline at end of file
+}
